# Changelog

## 1.0.0 (2025-05-30)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/AtomTickets/discovery-search/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* update SDK settings ([b0e79b5](https://github.com/AtomTickets/discovery-search/commit/b0e79b5b02a63d5746bb07edb1e822ee344de1cc))
* update SDK settings ([bce5884](https://github.com/AtomTickets/discovery-search/commit/bce5884fcf3528303658079e4f07324b5c231e56))
